### Name: hom.Dm.inpHOMSA
### Title: Map between IDs for genes in one organism to their predicted
###   paralogs in another
### Aliases: hom.Dm.inpAEDAE hom.Dm.inpANOGA hom.Dm.inpAPIME
###   hom.Dm.inpARATH hom.Dm.inpBOSTA hom.Dm.inpCAEBR hom.Dm.inpCAEEL
###   hom.Dm.inpCAERE hom.Dm.inpCANFA hom.Dm.inpCANGL hom.Dm.inpCIOIN
###   hom.Dm.inpCRYNE hom.Dm.inpDANRE hom.Dm.inpDEBHA hom.Dm.inpDICDI
###   hom.Dm.inpDROME hom.Dm.inpDROPS hom.Dm.inpENTHI hom.Dm.inpESCCO
###   hom.Dm.inpFUGRU hom.Dm.inpGALGA hom.Dm.inpGASAC hom.Dm.inpHOMSA
###   hom.Dm.inpKLULA hom.Dm.inpMACMU hom.Dm.inpMONDO hom.Dm.inpMUSMU
###   hom.Dm.inpORYSA hom.Dm.inpPANTR hom.Dm.inpRATNO hom.Dm.inpSACCE
###   hom.Dm.inpSCHPO hom.Dm.inpTETNI hom.Dm.inpXENTR hom.Dm.inpYARLI
### Keywords: datasets

### ** Examples

        x <- hom.Dm.inpAPIME
        # Get honeybee IDs that are paralogous to the pkg IDs
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five genes
          xx[1:5]
          # Get the first one
          xx[[1]]
        }

        #Now for the reverse map (honeybee IDs back to pkg paralog)
        x <- revmap(hom.Dm.inpAPIME)
        mapped_IDs <- mappedkeys(x)
        # Convert to a list
        xx <- as.list(x[mapped_IDs])
        if(length(xx) > 0) {
          # Get the paralogs for the first five IDs
          xx[1:5]
          # Get the first one
          xx[[1]]
        }         

    ## Not run: 
##D         #For the most common organisms, we ensure that you can map back
##D         #to an Entrez Gene ID by providing you with necessary maps in
##D         #the related organism based annotation packages.  The following
##D         #example shows how to get from an Entrez Gene ID for Human to
##D         #Entrez Gene IDs for Flies even though inparanoid does not map
##D         #to Entrez Gene IDs for either of these species.
##D 
##D         #You will have to include the appropriate packages for
##D         #humans:
##D         library("org.Hs.eg.db")
##D         #and for flies:
##D         library("org.Dm.eg.db")
##D         #And of course you will need the inparanoid package:
##D         library("hom.Hs.inp.db")
##D 
##D         #Start with some Human Entrez Gene IDs
##D         humanEGIds = c("1770","1769","4036")
##D 
##D         #Inparanoid uses ensembl protein IDs so start with
##D         #those. Notice that there will be many protein IDs returned for
##D         #a typical gene since there are many possible translations.
##D         humanProtIds = list()
##D         humanProtIds = mget(humanEGIds,org.Hs.egENSEMBLPROT)
##D 
##D         #Map the IDs that we can from inparanoid. Notice that by design,
##D         #inparanoid only represents each gene product with a single
##D         #translation product. Therefore your list should slim down a lot
##D         #during this step.
##D         rawFlyProtIds = mget(unlist(humanProtIds),hom.Hs.inpDROME,ifnotfound=NA)
##D         #This also means that we need to clean up the NAs from our result
##D         flyProtIds = rawFlyProtIds[!is.na(rawFlyProtIds)]
##D 
##D         #Then use the fly organism based packages to convert these IDs
##D         #back to an Entrex Gene ID again (this time for fly). 
##D         flyEGIds = mget(unlist(flyProtIds),org.Dm.egFLYBASEPROT2EG,ifnotfound=NA)
##D 
##D         #Now go ahead and have a look at the output
##D         flyEGIds
##D     
## End(Not run)




